module.exports = function(grunt) {

	var configPath = 'src/charts/config/**/*.js';
	var registersPath = 'src/charts/registers/**/*.js';
	var assetsPath = ['src/charts/assets/**/*.js'];
	var directivesPath = 'src/charts/assets/js/directives/**/*.js';
	var libsPath = 'src/charts/assets/js/libs/**/*.js';
	var zhChartLibPath = 'src/charts/assets/js/libs/zhCharts/**/*.js';

	grunt.initConfig({
		jshint: {
			all: ['GruntFile.js', directivesPath, zhChartLibPath]
		},
		watch: {
			pivotal: {
				files: [assetsPath],
				tasks: ['jshint']
			}
		},
		bump: {
		    options: {
		        files: ['bower.json', 'package.json'],
		        pushTo: 'origin',
		        commitFiles: ["-a"],
		        push: true
		    }
		},
		concat: {
			zh: {
				options: {
					process: function(src, filepath) {
						return '\n' + '// FILE: ' + filepath + '\n' + src;
					}
				},
				src: [configPath, registersPath, libsPath, directivesPath],
				dest: 'dist/zh-charts.js'
			}
		},
		uglify: {
			options: {
				mangle: false
			},
			target: {
				files: {
					'dist/zh-charts.min.js': ['dist/zh-charts.js']
				}
			}
		},
		copy: {
			main: {
				files: [{
					expand: true,
					cwd: 'src/charts/',
					src: 'templates/**/*',
					dest: 'dist/'
				},{
					expand: true,
					cwd: 'src/charts/assets/css',
					src: 'zh-charts.css',
					dest: 'dist/'
				}]
			}
		}
	});

	grunt.loadNpmTasks('grunt-contrib-jshint');
	grunt.loadNpmTasks('grunt-contrib-watch');
	grunt.loadNpmTasks('grunt-contrib-concat');
	grunt.loadNpmTasks('grunt-contrib-copy');
	grunt.loadNpmTasks('grunt-contrib-uglify');
	grunt.loadNpmTasks('grunt-bump');


	// Default task.
	grunt.registerTask('default', ['jshint', 'concat', 'uglify', 'copy']);
};